# Search Service for SCALE 25

```bash
python -m src.serve config.json
```

### 📁 Search Service Implementation

For an easy-to-use implementation of the search service, refer to the [`automated_search_service`](./automated_search_service) directory.
